# Module Test Results: codec

**Module:** codec
**Layer:** 1.unit
**Generated:** 04-Nov-2025 22:29:12
**Status:** FAILED

---

## Test Execution

**Command:** `python tests/1.unit/codec_tests/runner.py`

**Markers:** `xwsystem_unit`

**Options:**
- Verbose output (`-v`)
- Short traceback (`--tb=short`)
- Stop on first failure (`-x`)

---

## Result

❌ FAILED

**Exit Code:** 2

---

*Generated by eXonware test runner - Excellence Edition*
